Re: [PATCH] Reduce performance penalty for turned off traces
- From
Stefan Beller <sbeller@google.com>
- Date
- Nov 15, 2017, 19:14 UTC
- Message-ID
- <CAGZ79kb4Eo0AC4Z42_ks5_+Pcy4DrDCufNb=5J=g8L6pMnHd7A@mail.gmail.com>
- In-Reply-To
- <20171112141737.nmnsygm4wrhtkqwb@sigill.intra.peff.net>
On Sun, Nov 12, 2017 at 6:17 AM, Jeff King <peff@peff.net> wrote:
Show 7 quoted lines
> On Sat, Nov 11, 2017 at 07:28:58PM +0000, gennady.kupava@gmail.com wrote: > >> From: Gennady Kupava <gkupava@bloomberg.net> >> >> Signed-off-by: Gennady Kupava <gkupava@bloomberg.net> > > Thanks, and welcome to the list.
Welcome to the list!
> I did manually disable HAVE_VARIADIC_MACROS and confirmed that the > result builds and passes the test suite (though I suspect that GIT_TRACE > is not well exercised by the suite).
GIT_TRACE is exercised in the test suite (though I am not sure if it counts as well-exercised) in t7406-submodule-update.sh for example, which uses GIT_TRACE to obtain information about thread parallelism used by Git, as that is not observable otherwise, if we assume that performance tests in the standard test suite are not feasible.
Show 7 quoted lines
> I tried timing a simple loop like: > .... > Without your patch, the times for GIT_TRACE=1 and GIT_TRACE=0 are about > 500ms and 9ms respectively. > > After your patch, the GIT_TRACE=1 time remains the same but GIT_TRACE=0 > drops to 1ms.
So does that mean we can use a lot more tracing now?
Thanks, Stefan